@@ -665,32 +665,32 @@ class Worker(Process):
         try:
             job.perform()
 
-        except MaxConcurrencyInterrupt:
-            self.log.error("Max concurrency reached")
+        except MaxConcurrencyInterrupt as e:
+            self.log.error("Max concurrency reached: %s" % str(e))
             job._save_status("maxconcurrency", exception=True)
 
-        except RetryInterrupt:
-            self.log.error("Caught retry")
+        except RetryInterrupt as e:
+            self.log.error("Caught retry: %s" % str(e))
             job.save_retry(sys.exc_info()[1])
 
-        except MaxRetriesInterrupt:
-            self.log.error("Max retries reached")
+        except MaxRetriesInterrupt as e:
+            self.log.error("Max retries reached: %s" % str(e))
             job._save_status("maxretries", exception=True)
 
-        except AbortInterrupt:
-            self.log.error("Caught abort")
+        except AbortInterrupt as e:
+            self.log.error("Caught abort: %s" % str(e))
             job.save_abort()
 
         except TimeoutInterrupt:
             self.log.error("Job timeouted after %s seconds" % job.timeout)
             job._save_status("timeout", exception=True)
 
-        except JobInterrupt:
-            self.log.error("Job interrupted")
+        except JobInterrupt as e:
+            self.log.error("Job interrupted: %s" % str(e))
             job._save_status("interrupt", exception=True)
 
-        except Exception:
-            self.log.error("Job failed")
+        except Exception as e:
+            self.log.exception("Job %s failed: %s" % str(job.data['path']) % str(e))
             job._save_status("failed", exception=True)
 
         finally:
